@@ -166,7 +166,7 @@ class AutocompleteRestModel(AutocompleteModel):
             model = model_class(**unique_data)
 
         for key, value in data.items():
-            is_string = isinstance(value, (unicode, str))
+            is_string = isinstance(value, basestring)
             field = model_class._meta.get_field_by_name(key)[0]
 
             if getattr(field, 'rel', None) and is_string:
