@@ -4,7 +4,7 @@ from django.forms import fields
 from django.contrib.contenttypes.generic import GenericForeignKey
 from django.contrib.contenttypes.models import ContentType
 
-__all__ = ('GenericModelForm', 'GenericForeignKeyField')
+__all__ = ('GenericModelForm', 'GenericModelChoiceField')
 
 
 class GenericModelForm(forms.ModelForm):
@@ -57,16 +57,26 @@ class GenericModelForm(forms.ModelForm):
                     continue
 
                 setattr(self.instance, field.ct_field,
-                    ContentType.objects.get_for_model(value))
+                        ContentType.objects.get_for_model(value))
                 setattr(self.instance, field.fk_field, value.pk)
 
         return super(GenericModelForm, self).save(commit)
 
 
-class GenericForeignKeyField(fields.Field):
+class GenericModelChoiceField(fields.Field):
     """
     Simple form field that converts strings to models.
     """
+    def validate(self, value):
+        if not value and not self.required:
+            return True
+
+        value = self.prepare_value(value)
+        valid = self.widget.autocomplete(values=value).validate_values()
+
+        if not valid:
+            raise forms.ValidationError(u'%s cannot validate %s' % (
+                self, value))
 
     def prepare_value(self, value):
         """
@@ -79,7 +89,7 @@ class GenericForeignKeyField(fields.Field):
             return value
         elif isinstance(value, models.Model):
             return '%s-%s' % (ContentType.objects.get_for_model(value).pk,
-                value.pk)
+                              value.pk)
 
     def to_python(self, value):
         """
@@ -90,5 +100,11 @@ class GenericForeignKeyField(fields.Field):
             return value
 
         content_type_id, object_id = value.split('-')
-        model = ContentType.objects.get_for_id(content_type_id).model_class()
+        try:
+            content_type = ContentType.objects.get_for_id(content_type_id)
+        except ContentType.DoesNotExist:
+            raise forms.ValidationError(u'Wrong content type')
+        else:
+            model = content_type.model_class()
+
         return model.objects.get(pk=object_id)
