@@ -17,25 +17,21 @@ class WidgetTestCase(LiveServerTestCase):
         super(WidgetTestCase, cls).tearDownClass()
         cls.selenium.quit()
 
-    def autocomplete_visible(self, id=None):
-        if id is None: id = self.default_id
-        return self.autocomplete_element(id=None).is_displayed()
+    def autocomplete_visible(self):
+        return self.autocomplete_element().is_displayed()
 
-    def autocomplete_element(self, id=None):
-        if id is None: id = self.default_id
+    def autocomplete_element(self):
         return self.selenium.find_element_by_css_selector(
-            '.yourlabs-autocomplete.outer-container.id-%s' % id)
+            '.yourlabs-autocomplete')
 
-    def autocomplete_hilighted_choice_element(self, id=None):
-        if id is None: id = self.default_id
+    def autocomplete_hilighted_choice_element(self):
         return self.selenium.find_element_by_css_selector(
-            '.yourlabs-autocomplete.inner-container.id-%s [data-value].hilight' % id)
+            '.yourlabs-autocomplete [data-value].hilight')
 
 
-    def autocomplete_choice_elements(self, id=None):
-        if id is None: id = self.default_id
+    def autocomplete_choice_elements(self):
         return self.selenium.find_elements_by_css_selector(
-            '.yourlabs-autocomplete.inner-container.id-%s [data-value]' % id)
+            '.yourlabs-autocomplete [data-value]')
 
     def input_element(self, id=None):
         if id is None: id = self.default_id
